==> ovirt-web-ui-0.2.2.tar.gz: ovirt-web-ui-0.2.2/src/constants/index.js <==
// Keep alphabetically sorted

export const ADD_NEW_VM = 'ADD_NEW_VM'
export const CHANGE_FILTER_PERMISSION = 'CHANGE_FILTER_PERMISSION'
export const CLEAR_USER_MSGS = 'CLEAR_USER_MSGS'
export const EDIT_VM = 'EDIT_VM'
export const FAILED_EXTERNAL_ACTION = 'FAILED_EXTERNAL_ACTION'
export const GET_ALL_CLUSTERS = 'GET_ALL_CLUSTERS'
export const GET_ALL_OS = 'GET_ALL_OS'
export const GET_ALL_POOLS = 'GET_ALL_POOLS'
export const GET_ALL_TEMPLATES = 'GET_ALL_TEMPLATES'
export const GET_ALL_VMS = 'GET_ALL_VMS'
export const GET_CONSOLE_OPTIONS = 'GET_CONSOLE_OPTIONS'
export const GET_CONSOLE_VM = 'GET_CONSOLE_VM'
export const GET_POOL = 'GET_POOL'
export const LOGIN_FAILED = 'LOGIN_FAILED'
export const LOGIN = 'LOGIN'
export const LOGIN_SUCCESSFUL = 'LOGIN_SUCCESSFUL'
export const LOGOUT = 'LOGOUT'
export const PERSIST_STATE = 'PERSIST_STATE'
export const POOL_ACTION_IN_PROGRESS = 'POOL_ACTION_IN_PROGRESS'
export const REMOVE_MISSING_POOLS = 'REMOVE_MISSING_POOLS'
export const REMOVE_MISSING_VMS = 'REMOVE_MISSING_VMS'
export const REMOVE_POOL = 'REMOVE_POOL'
export const REMOVE_POOLS = 'REMOVE_POOLS'
export const REMOVE_VM = 'REMOVE_VM'
export const REMOVE_VMS = 'REMOVE_VMS'
export const RESTART_VM = 'RESTART_VM'
export const SAVE_CONSOLE_OPTIONS = 'SAVE_CONSOLE_OPTIONS'
export const SCHEDULER__1_MIN = 'SCHEDULER__1_MIN'
export const SELECT_POOL_DETAIL = 'SELECT_POOL_DETAIL'
export const SELECT_VM_DETAIL = 'SELECT_VM_DETAIL'
export const SET_ADMINISTATOR = 'SET_ADMINISTATOR'
export const SET_LOAD_IN_PROGRESS = 'SET_LOAD_IN_PROGRESS'
export const SET_OVIRT_API_VERSION = 'SET_OVIRT_API_VERSION'
export const SET_POOL_DETAIL_TO_SHOW = 'SET_POOL_DETAIL_TO_SHOW'
export const SET_USER_FILTER_PERMISSION = 'SET_USER_FILTER_PERMISSION'
export const SET_VM_CONSOLES = 'SET_VM_CONSOLES'
export const SET_VM_DETAIL_TO_SHOW = 'SET_VM_DETAIL_TO_SHOW'
export const SET_VM_DISKS = 'SET_VM_DISKS'
export const SHUTDOWN_VM = 'SHUTDOWN_VM'
export const START_POOL = 'START_POOL'
export const START_VM = 'START_VM'
export const SUSPEND_VM = 'SUSPEND_VM'
export const TOGGLE_OPTIONS = 'TOGGLE_OPTIONS'
export const UPDATE_ICONS = 'UPDATE_ICONS'
export const UPDATE_POOLS = 'UPDATE_POOLS'
export const UPDATE_VMPOOLS_COUNT = 'UPDATE_VMPOOLS_COUNT'
export const UPDATE_VMS = 'UPDATE_VMS'
export const VM_ACTION_IN_PROGRESS = 'VM_ACTION_IN_PROGRESS'

==> ovirt-web-ui-1.0.0.tar.gz: ovirt-web-ui-1.0.0/src/constants/index.js <==
// Keep alphabetically sorted
// TODO: sort alphabetically
// TODO: remove all constants except those used within sagas
export const CHANGE_FILTER_PERMISSION = 'CHANGE_FILTER_PERMISSION'
export const CHECK_TOKEN_EXPIRED = 'CHECK_TOKEN_EXPIRED'
export const CLEAR_USER_MSGS = 'CLEAR_USER_MSGS'
export const DOWNLOAD_CONSOLE_VM = 'DOWNLOAD_CONSOLE_VM'
export const FAILED_EXTERNAL_ACTION = 'FAILED_EXTERNAL_ACTION'
export const GET_ALL_CLUSTERS = 'GET_ALL_CLUSTERS'
export const GET_ALL_OS = 'GET_ALL_OS'
export const GET_ALL_POOLS = 'GET_ALL_POOLS'
export const GET_ALL_TEMPLATES = 'GET_ALL_TEMPLATES'
export const GET_ALL_VMS = 'GET_ALL_VMS'
export const GET_VM = 'GET_VM'
export const GET_CONSOLE_OPTIONS = 'GET_CONSOLE_OPTIONS'
export const GET_POOL = 'GET_POOL'
export const LOGIN_FAILED = 'LOGIN_FAILED'
export const LOGIN = 'LOGIN'
export const LOGIN_SUCCESSFUL = 'LOGIN_SUCCESSFUL'
export const LOGOUT = 'LOGOUT'
export const PERSIST_STATE = 'PERSIST_STATE'
export const POOL_ACTION_IN_PROGRESS = 'POOL_ACTION_IN_PROGRESS'
export const REFRESH_DATA = 'REFRESH_DATA'
export const REMOVE_MISSING_POOLS = 'REMOVE_MISSING_POOLS'
export const REMOVE_MISSING_VMS = 'REMOVE_MISSING_VMS'
export const REMOVE_POOL = 'REMOVE_POOL'
export const REMOVE_POOLS = 'REMOVE_POOLS'
export const REMOVE_VM = 'REMOVE_VM'
export const REMOVE_VMS = 'REMOVE_VMS'
export const RESTART_VM = 'RESTART_VM'
export const SAVE_CONSOLE_OPTIONS = 'SAVE_CONSOLE_OPTIONS'
export const SCHEDULER__1_MIN = 'SCHEDULER__1_MIN'
export const SELECT_POOL_DETAIL = 'SELECT_POOL_DETAIL'
export const SELECT_VM_DETAIL = 'SELECT_VM_DETAIL'
export const SET_ADMINISTATOR = 'SET_ADMINISTATOR'
export const SET_LOAD_IN_PROGRESS = 'SET_LOAD_IN_PROGRESS'
export const SET_OVIRT_API_VERSION = 'SET_OVIRT_API_VERSION'
export const SET_USER_FILTER_PERMISSION = 'SET_USER_FILTER_PERMISSION'
export const SET_VM_CONSOLES = 'SET_VM_CONSOLES'
export const SET_VM_DISKS = 'SET_VM_DISKS'
export const SET_VM_SESSIONS = 'SET_VM_SESSIONS'
export const SHUTDOWN_VM = 'SHUTDOWN_VM'
export const START_POOL = 'START_POOL'
export const START_VM = 'START_VM'
export const SUSPEND_VM = 'SUSPEND_VM'
export const TOGGLE_OPTIONS = 'TOGGLE_OPTIONS'
export const UPDATE_ICONS = 'UPDATE_ICONS'
export const UPDATE_POOLS = 'UPDATE_POOLS'
export const UPDATE_VMPOOLS_COUNT = 'UPDATE_VMPOOLS_COUNT'
export const UPDATE_VMS = 'UPDATE_VMS'
export const VM_ACTION_IN_PROGRESS = 'VM_ACTION_IN_PROGRESS'
